from setuptools import setup

setup(name='prob_dist_timi',
      version='1.0',
      description='Gaussian and Binomial distributions',
      author='Olusegun Timilehin',
      packages=['prob_dist_timi'],
      zip_safe=False)
